@@ -150,13 +150,17 @@ static bool probe_enabled = false;
 // The function which should be called once as soon as possible after the process is started
 static bool init_proc_once_flag = false;
 void InitProcessCallOnce()
+{
+	InitProcessCallOnceEx(false);
+}
+void InitProcessCallOnceEx(int restricted_mode)
 {
 	if (init_proc_once_flag == false)
 	{
 		init_proc_once_flag = true;
 
 #ifdef	OS_WIN32
-		MsInitProcessCallOnce();
+		MsInitProcessCallOnce(restricted_mode);
 #endif	// OS_WIN32
 	}
 }
